local L = BAFK_locale()
local addonName = "Broker_AFK"
local LaddonName = L[addonName]
local addonTag = "<"..addonName..">"
Broker_AFK = {}
local addon = Broker_AFK
local minimapIcon = LibStub("LibDBIcon-1.0")
local optionsFrame
local _G = getfenv(0)
BAFK_svnrev = {}
BAFK_svnrev["Broker_AFK.lua"] = tonumber(("$Revision: 17 $"):match("%d+"))
local defaults = { 
 profile = {
  debug = false,
  timeaway = true,
  playerframe = true,
  autocleartalk = true,
  autoreplyafk = true,
  autoreplydnd = false,
  autoreply = {
    guild = true,
    officer = true,
    party = true,
    raid = true,
    say = true,
    yell = true,
    ready_check = true,
  },
  autobusy = {
    instance = false,
    raid = true,
    arena = true,
    battleground = true,
  },
  aliases = {},
  ldbtext = {
    avail = false,
    afk = true,
    dnd = true,
  },
  minimap = {
      hide = false,
  },
  afkalert = "none",
  idlealert = "Sound\\INTERFACE\\ReadyCheck.ogg",
 }
}
local settings = defaults.profile
local LDB, LDBo
local current_status = nil
local current_event = nil
local current_status_time = nil
local current_message = nil
local elapsed_time = 0
local timeaway = ""
local autobusy_override_zone
local outdoor_bg = {}
local status_icon = {
  avail = FRIENDS_TEXTURE_ONLINE,
  afk   = FRIENDS_TEXTURE_AFK,
  dnd   = FRIENDS_TEXTURE_DND,
}
local status_text = {
  avail = FRIENDS_LIST_AVAILABLE,
  afk   = FRIENDS_LIST_AWAY,
  dnd   = FRIENDS_LIST_BUSY,
}
local chats = {
  ["CHAT_MSG_GUILD"] = "GUILD", 
  ["CHAT_MSG_OFFICER"] = "OFFICER",
  ["CHAT_MSG_PARTY"] = "PARTY", 
  ["CHAT_MSG_PARTY_LEADER"] = "PARTY",
  ["CHAT_MSG_RAID"] = "RAID", 
  ["CHAT_MSG_RAID_LEADER"] = "RAID",
  ["CHAT_MSG_RAID_WARNING"] = "RAID",
  ["CHAT_MSG_SAY"] = "SAY",
  ["CHAT_MSG_YELL"] = "YELL",
  ["READY_CHECK"] = "READY_CHECK"
}
local alertSounds = {
  ["none"] = "None",
  ["Sound\\Doodad\\BellTollAlliance.ogg"] = "Bell1",
  ["Sound\\Doodad\\BellTollHorde.ogg"]    = "Bell2",
  ["Sound\\Doodad\\BellTollNightElf.ogg"] = "Bell3",
  ["Sound\\Doodad\\BellTollTribal.ogg"]   = "Bell4",
  ["Sound\\Doodad\\DireMaulCrystalGeneratorOpen.ogg"]   = "Crunch",
  ["Sound\\Events\\scourge_horn.ogg"]                   = "Horn",
  ["Sound\\Events\\EbonHold_WomanScream4_01.ogg"]       = "Scream",
  ["Sound\\creature\\Peon\\PeonPissed2.ogg"]            = "Busy",
  ["Sound\\creature\\Peasant\\PeasantWarcry1.ogg"]      = "Yaaa",
  ["Sound\\Creature\\Murloc\\mMurlocAggroOld.ogg"]      = "Murloc",
  ["Sound\\Creature\\Cow\\CowDeath.ogg"]                = "Moo",
  ["Sound\\INTERFACE\\AlarmClockWarning1.ogg"]   = "Alarm1",
  ["Sound\\INTERFACE\\AlarmClockWarning2.ogg"]   = "Alarm2",
  ["Sound\\INTERFACE\\AlarmClockWarning3.ogg"]   = "Alarm3",
  ["Sound\\INTERFACE\\LFG_Rewards.ogg"]   = "Bong",
  ["Sound\\INTERFACE\\RaidWarning.ogg"]   = "Warn1",
  ["Sound\\INTERFACE\\ReadyCheck.ogg"]   = "Warn2",
  --["Sound\\\\.ogg"]   = "",
  --["Sound\\\\.ogg"]   = "",
  --["Sound\\\\.ogg"]   = "",
}

local function PlayAlert(alertType, val)
  if alertType == "afk" then
    val = val or settings.afkalert
  else
    val = val or settings.idlealert
  end
  if not val or val == "none" then return end
  local sound = alertSounds[val]
  if not sound then return end
  PlaySoundFile(val,"Master")
end

local rezone = {
  ["ZONE_CHANGED"] = true, ["ZONE_CHANGED_INDOORS"] = true, ["ZONE_CHANGED_NEW_AREA"] = true, ["PLAYER_ENTERING_WORLD"] = true, 
 -- ["PARTY_MEMBERS_CHANGED"] = true, ["RAID_ROSTER_UPDATE"] = true
}

local SEC_TO_MINUTE_FACTOR = 1/60;
local SEC_TO_HOUR_FACTOR = SEC_TO_MINUTE_FACTOR*SEC_TO_MINUTE_FACTOR;

local function chatMsg(msg)
     DEFAULT_CHAT_FRAME:AddMessage(LaddonName..": "..msg)
end
local function debug(msg)
  if settings.debug then
     chatMsg(msg)
  end
end

local frame = CreateFrame("Button", addonName.."HiddenFrame", UIParent)
frame:RegisterEvent("ADDON_LOADED");
frame:RegisterEvent("PLAYER_FLAGS_CHANGED");
frame:RegisterEvent("PLAYER_ENTERING_WORLD");
frame:RegisterEvent("CHAT_MSG_SYSTEM");
for c,_ in pairs(chats) do
  frame:RegisterEvent(c) 
end
for e,_ in pairs(rezone) do
  frame:RegisterEvent(e) 
end

local function ZoneCheck()
  if current_event == "PLAYER_ENTERING_WORLD" then return end -- player flags unreliable
  local i, t = IsInInstance()

  local set
  if t == "none" then
    local id = outdoor_bg[GetRealZoneText()]
    if id then
      local _,_, isActive = GetWorldPVPAreaInfo(id)
      if isActive then
        set = "battleground"
      end
    end
  elseif t == "pvp" then
    set = "battleground"
  elseif t == "arena" then
    set = "arena"
  elseif t == "party" then
    set = "instance"
  elseif t == "raid" then
    set = "raid"
  end
  if not set or not settings.autobusy[set] then
    if current_status == "dnd" and current_message and string.match(current_message, addonTag) then
      debug("Clearing auto-busy")
      --current_status = "avail"
      current_message = nil
      SendChatMessage("", "DND")
    end
    return
  elseif settings.autobusy[set] and current_status == "avail" and autobusy_override_zone ~= GetRealZoneText() then
    debug("Setting auto-busy")
    --current_status = "dnd"
    current_message = addonTag.." "..UnitName("player").." "..L["is busy with"].." "..L[set]
    SendChatMessage(current_message, "DND")
  end
end

local function OnSendChat(text, chatType, lang, channel)
  if chatType == "AFK" or chatType == "DND" then
    if chatType == "DND" and current_status == "dnd" and current_message and 
       string.match(current_message, addonTag) and not string.match(text, addonTag) then
      autobusy_override_zone = GetRealZoneText()
      debug("Set autobusy_override_zone: "..autobusy_override_zone)
    end
    if text and #text > 0 then
      current_message = text
    else
      current_message = nil
    end
  elseif current_status == "afk" and addon:autoclearMode() == "talk" 
        and not string.match(text, addonTag) then
    if chatType == "CHANNEL" and channel and channel > 0 then
      local _,name = GetChannelName(channel)
      if string.match(name,"^TCForwarder") or string.match(name,"^LFGForwarder") then 
        return -- ignore channel messages from addons
      end
    end
    debug("Auto-clearing AFK on chat: "..(chatType or "").." : "..(text or "").." "..(channel or ""))
    current_status = "avail"
    SendChatMessage("", "AFK")
  end
end

local function OnRecvChat(event, text, sender, ...)
  local reply
  if event == "CHAT_MSG_SYSTEM" then
    if string.match(text, IDLE_MESSAGE) then
      PlayAlert("idle")
    end
    return
  elseif event == "READY_CHECK" then
    if settings.autoreply.ready_check and current_status == "afk" and settings.autoreplyafk then
      debug("READY_CHECK reply")
      reply = UnitInRaid("player") and "RAID" or "PARTY" 
    end
  elseif sender ~= UnitName("player") then
    --myprint(event, text, sender, ...)
    local channel
    if ((current_status == "afk" and settings.autoreplyafk) or 
        (current_status == "dnd" and settings.autoreplydnd)) and
       settings.autoreply[string.lower(chats[event])] and 
       not string.match(text, addonTag) then
       local gotone 
       text = " "..text.." "
       for w in string.gmatch(text,"(%a+)") do
         if settings.aliases[string.upper(w)] and 
	    string.match(text,"[%p%s]+"..w.."[%p%s]+") then
           debug("Auto-Reply Matched '"..w.."' in "..sender..": "..text)
	   gotone = true
	   break
	 end
       end
       if gotone then
         reply = chats[event]
       end
    end
  end
  if reply then
    local msg = addonTag.." "..UnitName("player").." "..L["is currently"].." "..status_text[current_status]
    if current_message and #current_message > 0 then
      msg = msg..": "..current_message
    end
    if timeaway and #timeaway > 0 then
      msg = msg.." ("..timeaway..")"
    end
    SendChatMessage(msg, reply)
  end
end

local function table_clone(t)
  if not t then return nil
  elseif type(t) == "table" then
    local res = {}
    for k,v in pairs(t) do
      res[table_clone(k)] = table_clone(v)
    end
    return res
  else
    return t
  end
end

local function initial_caps(s)
  s = string.lower(s)
  s = string.gsub(s,"^(%a)",function(m) return string.upper(m) end)
  s = string.gsub(s,"(%s)(%a)",function(s,m) return s..string.upper(m) end)
  return s
end

function addon:RefreshConfig()
     settings = addon.db.profile
     addon.settings = settings
     for k,v in pairs(defaults.profile) do
        if settings[k] == nil then 
	  settings[k] = table_clone(v)
	end
     end
     settings.aliases[string.upper(UnitName("player"))] = true
     settings.loaded = true
end

local function OnInitialize()
     addon.db = LibStub("AceDB-3.0"):New("Broker_AFKDB", defaults)
     addon:RefreshConfig()
     addon:SetupVersion()
     local options = addon:myOptions()
     LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, options, {"brokerafk", "bafk"})
     optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName, addonName, nil, "general")
     optionsFrame.default = function() 
       for k,v in pairs(defaults.profile) do settings[k] = table_clone(v) end 
       addon:RefreshConfig()
       if InterfaceOptionsFrame:IsShown() then
         addon:Config(); addon:Config()
       end
     end
     options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(addon.db)
     LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName, L["Profiles"], addonName, "profiles")

     addon.db.RegisterCallback(addon, "OnProfileChanged", "RefreshConfig")
     addon.db.RegisterCallback(addon, "OnProfileCopied", "RefreshConfig")
     addon.db.RegisterCallback(addon, "OnProfileReset", "RefreshConfig")
     addon.db.RegisterCallback(addon, "OnDatabaseReset", "RefreshConfig")

     addon:setupLDB()

     hooksecurefunc("SendChatMessage", OnSendChat)

     for i = 1,2 do
       local _,n = GetWorldPVPAreaInfo(i)
       outdoor_bg[n] = i
     end
end

local function OnEvent(frame, event, name, ...)
  if event == "ADDON_LOADED" and name == addonName then
     debug("ADDON_LOADED: "..name)
     OnInitialize()
  elseif event == "PLAYER_FLAGS_CHANGED" or event == "PLAYER_ENTERING_WORLD" or rezone[event] then
     debug(event)
     current_event = event
     addon:Update()
     current_event = nil
  elseif chats[event] or event == "CHAT_MSG_SYSTEM" then
     OnRecvChat(event, name, ...)
  end
end
frame:SetScript("OnEvent", OnEvent);

function addon:SetupVersion()
   local svnrev = 0
   local T_svnrev = BAFK_svnrev
   T_svnrev["X-Build"] = tonumber((GetAddOnMetadata(addonName, "X-Build") or ""):match("%d+"))
   T_svnrev["X-Revision"] = tonumber((GetAddOnMetadata(addonName, "X-Revision") or ""):match("%d+"))
   for _,v in pairs(T_svnrev) do -- determine highest file revision
     if v and v > svnrev then
       svnrev = v
     end
   end
   addon.revision = svnrev

   T_svnrev["X-Curse-Packaged-Version"] = GetAddOnMetadata(addonName, "X-Curse-Packaged-Version")
   T_svnrev["Version"] = GetAddOnMetadata(addonName, "Version")
   addon.version = T_svnrev["X-Curse-Packaged-Version"] or T_svnrev["Version"] or "@"
   if string.find(addon.version, "@") then -- dev copy uses "@.project-version.@"
      addon.version = "r"..svnrev
   end
end

function addon:Config()
  if optionsFrame then
    if ( InterfaceOptionsFrame:IsShown() ) then
      InterfaceOptionsFrame:Hide();
    else
      InterfaceOptionsFrame_OpenToCategory(optionsFrame)
    end
  end
end

local function OnUpdate(f,el) addon:Update(el) end

function addon:Update(elapsed)
  if elapsed then -- optimize away unnecessary updates
     elapsed_time = elapsed_time + elapsed
     if elapsed_time < 0.25 then
       return
     end
  else
     elapsed_time = 0.0
  end

  local new_status = "avail"
  if (IsChatAFK()) then
    new_status = "afk"
  elseif (IsChatDND()) then
    new_status = "dnd"
  end

  if new_status ~= current_status then -- change in status
    current_status_time = GetTime()
    current_status = new_status
    if current_status == "afk" then
      PlayAlert("afk")
    end
  end

  if current_status == "avail" or not settings.playerframe then
    PlayerName:SetText(UnitName("player"))
  else
    PlayerName:SetText("|T"..status_icon[current_status]..":0|t "..
                       UnitName("player").." <"..status_text[current_status]..">")
  end
  if settings.timeaway and current_status == "afk" then
     frame:SetScript("OnUpdate", OnUpdate);
     local total_time = GetTime() - current_status_time;
     local hour = min(floor(total_time*SEC_TO_HOUR_FACTOR), 99);
     local minute = mod(total_time*SEC_TO_MINUTE_FACTOR, 60);
     local second = mod(total_time, 60);
     if hour >= 1 then
       timeaway = string.format(" %d:%02d:%02d", hour, minute, second)
     elseif minute >= 1 then
       timeaway = string.format(" %d:%02d", minute, second)
     else
       timeaway = string.format(" :%02d",second)
     end
     if addon.tooltip and addon.tooltipOwner == addon.tooltip:GetOwner() then
       BAFK_OnTooltipShow(addon.tooltip)
     end
  else
     timeaway = ""
     frame:SetScript("OnUpdate", nil);
  end

  if LDBo then
    if settings.ldbtext[current_status] then
      LDBo.text = status_text[current_status]..timeaway
    else
      LDBo.text = ""
    end
    LDBo.icon = status_icon[current_status]
  end

  ZoneCheck()
end

function BAFK_OnClick(frame, button)
   if addon.tooltip and addon.tooltip:IsVisible() then
      addon.tooltip:Hide()
      addon.tooltip = nil
   end
   if ( IsShiftKeyDown() ) then
	debug("shift-click "..button)
   elseif button == "LeftButton" then
        debug("status menu")
        ToggleDropDownMenu(1, nil, FriendsFrameStatusDropDown, "cursor", 0, 0)
   elseif button == "RightButton" then
        debug("config menu")
        addon:Config()
        --ToggleDropDownMenu(1, nil, addon.DropDownMenu, "cursor", 0, 0)
   else
	debug("click "..button)
   end
end

function BAFK_OnTooltipShow(tooltip)
     addon.tooltip = tooltip
     addon.tooltipOwner = tooltip:GetOwner()
     if tooltip and tooltip.AddLine then
         tooltip:SetText(LaddonName.." "..addon.version)
         tooltip:AddLine(string.format(FRIENDS_LIST_STATUS_TOOLTIP, status_text[current_status])..timeaway)
	 if current_status ~= "avail" and current_message then
	   tooltip:AddLine(L["Message"]..": |cffffffff"..current_message)
	 end
         tooltip:AddLine("|cffff8040"..L["Left Click"].."|r "..L["to set status"])
         tooltip:AddLine("|cffff8040"..L["Right Click"].."|r "..L["for config"])
         tooltip:Show()
     end
end

function addon:setupLDB()
  if LDB then
    return
  end
  if AceLibrary and AceLibrary:HasInstance("LibDataBroker-1.1") then
    LDB = AceLibrary("LibDataBroker-1.1")
  elseif LibStub then
    LDB = LibStub:GetLibrary("LibDataBroker-1.1",true)
  end
  if LDB then
    LDBo = LDB:NewDataObject(LaddonName, {
        type = "data source",
        label = LaddonName,
	text = LaddonName,
        OnClick = BAFK_OnClick,
        OnTooltipShow = BAFK_OnTooltipShow,
        OnTooltipHide = function() addon.tooltip = nil end,
     })
     debug("LDB created!")
  end 

  addon:Update()

  if LDBo then 
    minimapIcon:Register(addonName, LDBo, settings.minimap)
    if settings.minimap.hide then
      minimapIcon:Hide(addonName)
    else
      minimapIcon:Show(addonName)
    end
  end

end

--[[
addon.DropDownMenu = CreateFrame("Frame", addonName.."_DropDownMenu")
addon.DropDownMenu.displayMode = "MENU"
addon.DropDownMenu.onHide = function(...)
        MenuParent = nil
        MenuItem = nil
end

local menuinfo = {}
addon.DropDownMenu.initialize = function(self, level)
        if not level then return end
        wipe(menuinfo)
        if level == 1 then
                -- Create the title of the menu
                menuinfo.isTitle = 1
                menuinfo.text = LaddonName.." "..addon.version
                menuinfo.notCheckable = 1
                UIDropDownMenu_AddButton(menuinfo, level)

                menuinfo.disabled     = nil
                menuinfo.isTitle      = nil
                menuinfo.notCheckable = nil

                local options = { "foo" }
                for _,key in pairs(options) do
                        menuinfo.text = L[key] 
                        menuinfo.arg1 = key
                        menuinfo.func = function(button, arg1)
                               settings[key] = not settings[key]
        		       chatMsg(L[arg1].." "..(settings[key] and VIDEO_OPTIONS_ENABLED or VIDEO_OPTIONS_DISABLED))
                        end
                        menuinfo.checked = (settings[key])
                        UIDropDownMenu_AddButton(menuinfo, level)
                end

                -- Close menu item
                menuinfo.text         = CLOSE
                menuinfo.func         = function() CloseDropDownMenus() end
                menuinfo.checked      = nil
                menuinfo.notCheckable = 1
                UIDropDownMenu_AddButton(menuinfo, level)
        end
end
--]]

function addon:autoclearMode(set) 
  local gameset = tonumber(GetCVar("autoClearAFK")) > 0
  local talkset = settings.autocleartalk
  if not set then
    if gameset then return "all"
    elseif talkset then return "talk"
    else return "none"
    end
  else
   if set == "all" then      gameset = true; talkset = false;
   elseif set == "talk" then gameset = false; talkset = true;
   elseif set == "none" then gameset = false; talkset = false;
   else
     chatMsg("ERROR bad autoclearMode")
   end
   settings.autocleartalk = talkset
   local cb = InterfaceOptionsControlsPanelAutoClearAFK
   if cb then
      debug("SetChecked("..tostring(val)..")")
      cb:SetChecked(gameset)
      InterfaceOptionsPanel_CheckButton_Update(cb)
   end
   SetCVar("autoClearAFK", (gameset and "1") or "0")
   return set
  end
end

function addon:myOptions()
  return {
  type = "group",
  set = function(info,val) 
          local s = settings ; for i = 2,#info-1 do s = s[info[i]] end
          s[info[#info]] = val; debug(info[#info].." set to: "..tostring(val)) 
          addon:Update()
        end,
  get = function(info) 
          local s = settings ; for i = 2,#info-1 do s = s[info[i]] end
          return s[info[#info]] end,
  args = {
   general = {
    type = "group",
    inline = true,
    name = L["General"],
    args = {
      debug = {
        name = L["Debug"],
        desc = L["Toggle debugging output"],
        type = "toggle",
        guiHidden = true,
      },
      playerframe = {
        order = 10,
        name = L["Player Frame"],
        desc = L["Display status in player name unit frame"],
        type = "toggle",
      },
      awayheader = {
        order = 19,
	name = status_text["afk"],
	type = "header",
      },
      timeaway = {
        order = 20,
        name = L["Time Away"],
        desc = L["Display how long you've been Away"],
        type = "toggle",
      },
      autoclear = {
        order = 30,
        name = L["Auto Cancel Away Mode Upon"],
        type = "select",
	--width = "double",
	values = { ["all"] = L["Movement or Talking"], ["talk"] = L["Talking only"], ["none"] = L["Never"] },
        get = function(info) return addon:autoclearMode() end,
        set = function(info,val) 
	        addon:autoclearMode(val)
                debug(info[#info].." set to: "..tostring(val))
              end,
      },
      afkalert = {
        order = 40,
	cmdHidden = true,
	name = L["Away Alert Sound"],
	desc = L["Sound to play when you go AFK"],
	type = "select",
	values = alertSounds,
	validate = function(info, val) PlayAlert("afk",val); return true end,
      },
      idlealert = {
        order = 42,
	cmdHidden = true,
	name = L["Idle Alert Sound"],
	desc = L["Sound to play when you about to be logged out for inactivity"],
	type = "select",
	values = alertSounds,
	validate = function(info, val) PlayAlert("idle",val); return true end,
      },
      autoreplyheader = {
        order = 49,
	name = L["Auto-Reply"],
	type = "header",
      },
      autoreplyafk = {
        order = 50,
        name = L["Auto-Reply when Away"],
        desc = L["Automatically reply to your name in chat when away"],
        type = "toggle",
      },
      autoreplydnd = {
        order = 60,
        name = L["Auto-Reply when Busy"],
        desc = L["Automatically reply to your name in chat when busy"],
        type = "toggle",
      },
      autoreply = {
        order = 70,
        type = "group",
        guiInline = true,
        disabled = function () return not (settings.autoreplyafk or settings.autoreplydnd) end,
        name = L["Auto-Reply Channels"],
        args = (function() 
	  local t,i = {},1
	  for _,c in pairs(chats) do
	    lc = string.lower(c)
	    t[lc] = {
              type = "toggle",
	      order = (c == "READY_CHECK" and 1000 or i),
	      name = (_G["CHAT_MSG_"..c] or _G[c]),
	      desc = L["Automatically reply to your name in"].." "..(_G["CHAT_MSG_"..c] or _G[c])
	    }
	    i = i + 1
	  end
	  return t
	end)(),
      },
      aliases = {
        order = 80,
        disabled = function () return not (settings.autoreplyafk or settings.autoreplydnd) end,
	name = L["Auto-Reply Aliases"],
	desc = L["Comma-seperated list of character names to recognize"],
	type = "input",
	width = "full",
        get = function(info) 
	   local l = ""
	   for a,_ in pairs(settings.aliases) do
	     if #l > 0 then l = l..", " end
	     l = l..initial_caps(a)
	   end
	   return l 
	end,
        set = function(info,val) 
	  settings.aliases = {}
	  val = string.gsub(val,"[%p%s%c]",",")
	  val = ","..val..","
	  val = string.upper(val)
	  string.gsub(val,",([^,]+)", function(a) settings.aliases[a] = true; return "" end)
	end
      },
      mischeader = {
        order = 89,
	name = "", 
	type = "header",
      },
      autobusy = {
        order = 90,
        type = "group",
        guiInline = true,
        name = L["Auto Set Busy in"]..":",
        args = (function() 
	  local t = {}
	  for w,_ in pairs(defaults.profile.autobusy) do
	    t[w] = {
              type = "toggle",
	      name = initial_caps(L[w]),
	      desc = L["Automatically set Busy when in"].." "..L[w]
	    }
	  end
	  return t
	end)(),
      },
      ldbtext = {
        order = 100,
        type = "group",
        guiInline = true,
        name = L["LDB Text"],
        args = {
         avail = {
          order = 110,
          name = status_text.avail,
          desc = L["Show LDB text for"].." "..status_text.avail,
          type = "toggle",
         },
         afk = {
          order = 120,
          name = status_text.afk,
          desc = L["Show LDB text for"].." "..status_text.afk,
          type = "toggle",
         },
         dnd = {
          order = 130,
          name = status_text.dnd,
          desc = L["Show LDB text for"].." "..status_text.dnd,
          type = "toggle",
         },
        },
      },
     },
   }
  }
}
end
